@@ -21,7 +21,6 @@ from cleo.formatters.style import Style
 from cleo.io.buffered_io import BufferedIO
 from cleo.io.outputs.output import Verbosity
 from poetry.core.packages.package import Package
-from poetry.core.packages.utils.link import Link
 from poetry.core.packages.utils.utils import path_to_url
 
 from poetry.factory import Factory
@@ -473,11 +472,11 @@ def test_execute_works_with_ansi_output(
 
     # fmt: off
     expected = [
-        "\x1b[39;1mPackage operations\x1b[39;22m: \x1b[34m1\x1b[39m install, \x1b[34m0\x1b[39m updates, \x1b[34m0\x1b[39m removals",  # noqa: E501
-        "\x1b[34;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[39;1m1.0.0a5\x1b[39;22m\x1b[39m)\x1b[39m: \x1b[34mPending...\x1b[39m",  # noqa: E501
-        "\x1b[34;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[39;1m1.0.0a5\x1b[39;22m\x1b[39m)\x1b[39m: \x1b[34mDownloading...\x1b[39m",  # noqa: E501
-        "\x1b[34;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[39;1m1.0.0a5\x1b[39;22m\x1b[39m)\x1b[39m: \x1b[34mInstalling...\x1b[39m",  # noqa: E501
-        "\x1b[32;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[32m1.0.0a5\x1b[39m\x1b[39m)\x1b[39m",  # finished  # noqa: E501
+        "\x1b[39;1mPackage operations\x1b[39;22m: \x1b[34m1\x1b[39m install, \x1b[34m0\x1b[39m updates, \x1b[34m0\x1b[39m removals",
+        "\x1b[34;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[39;1m1.0.0a5\x1b[39;22m\x1b[39m)\x1b[39m: \x1b[34mPending...\x1b[39m",
+        "\x1b[34;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[39;1m1.0.0a5\x1b[39;22m\x1b[39m)\x1b[39m: \x1b[34mDownloading...\x1b[39m",
+        "\x1b[34;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[39;1m1.0.0a5\x1b[39;22m\x1b[39m)\x1b[39m: \x1b[34mInstalling...\x1b[39m",
+        "\x1b[32;1m•\x1b[39;22m \x1b[39mInstalling \x1b[39m\x1b[36mcleo\x1b[39m\x1b[39m (\x1b[39m\x1b[32m1.0.0a5\x1b[39m\x1b[39m)\x1b[39m",  # finished
     ]
     # fmt: on
 
@@ -583,21 +582,23 @@ def test_executor_should_delete_incomplete_downloads(
     pool: RepositoryPool,
     mock_file_downloads: None,
     env: MockEnv,
-    fixture_dir: FixtureDirGetter,
 ) -> None:
-    fixture = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
-    destination_fixture = tmp_path / "tomlkit-0.5.3-py2.py3-none-any.whl"
-    shutil.copyfile(str(fixture), str(destination_fixture))
+    cached_archive = tmp_path / "tomlkit-0.5.3-py2.py3-none-any.whl"
+
+    def download_fail(*_: Any) -> None:
+        cached_archive.touch()  # broken archive
+        raise Exception("Download error")
+
     mocker.patch(
         "poetry.installation.executor.Executor._download_archive",
-        side_effect=Exception("Download error"),
+        side_effect=download_fail,
     )
     mocker.patch(
-        "poetry.installation.executor.ArtifactCache.get_cached_archive_for_link",
+        "poetry.utils.cache.ArtifactCache._get_cached_archive",
         return_value=None,
     )
     mocker.patch(
-        "poetry.installation.executor.ArtifactCache.get_cache_directory_for_link",
+        "poetry.utils.cache.ArtifactCache.get_cache_directory_for_link",
         return_value=tmp_path,
     )
 
@@ -608,7 +609,7 @@ def test_executor_should_delete_incomplete_downloads(
     with pytest.raises(Exception, match="Download error"):
         executor._download(Install(Package("tomlkit", "0.5.3")))
 
-    assert not destination_fixture.exists()
+    assert not cached_archive.exists()
 
 
 def verify_installed_distribution(
@@ -669,7 +670,7 @@ def test_executor_should_not_write_pep610_url_references_for_cached_package(
     package.files = [
         {
             "file": "demo-0.1.0-py2.py3-none-any.whl",
-            "hash": "sha256:70e704135718fffbcbf61ed1fc45933cfd86951a744b681000eaaa75da31f17a",  # noqa: E501
+            "hash": "sha256:70e704135718fffbcbf61ed1fc45933cfd86951a744b681000eaaa75da31f17a",
         }
     ]
 
@@ -696,7 +697,7 @@ def test_executor_should_write_pep610_url_references_for_wheel_files(
     package.files = [
         {
             "file": "demo-0.1.0-py2.py3-none-any.whl",
-            "hash": "sha256:70e704135718fffbcbf61ed1fc45933cfd86951a744b681000eaaa75da31f17a",  # noqa: E501
+            "hash": "sha256:70e704135718fffbcbf61ed1fc45933cfd86951a744b681000eaaa75da31f17a",
         }
     ]
 
@@ -729,7 +730,7 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_files(
     package.files = [
         {
             "file": "demo-0.1.0.tar.gz",
-            "hash": "sha256:9fa123ad707a5c6c944743bf3e11a0e80d86cb518d3cf25320866ca3ef43e2ad",  # noqa: E501
+            "hash": "sha256:9fa123ad707a5c6c944743bf3e11a0e80d86cb518d3cf25320866ca3ef43e2ad",
         }
     ]
 
@@ -823,7 +824,7 @@ def test_executor_should_write_pep610_url_references_for_wheel_urls(
     if is_artifact_cached:
         link_cached = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
         mocker.patch(
-            "poetry.installation.executor.ArtifactCache.get_cached_archive_for_link",
+            "poetry.utils.cache.ArtifactCache.get_cached_archive_for_link",
             return_value=link_cached,
         )
     download_spy = mocker.spy(Executor, "_download_archive")
@@ -838,7 +839,7 @@ def test_executor_should_write_pep610_url_references_for_wheel_urls(
     package.files = [
         {
             "file": "demo-0.1.0-py2.py3-none-any.whl",
-            "hash": "sha256:70e704135718fffbcbf61ed1fc45933cfd86951a744b681000eaaa75da31f17a",  # noqa: E501
+            "hash": "sha256:70e704135718fffbcbf61ed1fc45933cfd86951a744b681000eaaa75da31f17a",
         }
     ]
 
@@ -861,9 +862,13 @@ def test_executor_should_write_pep610_url_references_for_wheel_urls(
     else:
         assert package.source_url is not None
         download_spy.assert_called_once_with(
-            mocker.ANY, operation, Link(package.source_url)
+            mocker.ANY,
+            operation,
+            package.source_url,
+            dest=mocker.ANY,
         )
-        assert download_spy.spy_return.exists(), "cached file should not be deleted"
+        dest = download_spy.call_args.args[3]
+        assert dest.exists(), "cached file should not be deleted"
 
 
 @pytest.mark.parametrize(
@@ -900,12 +905,12 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
     )
     download_spy = mocker.spy(Executor, "_download_archive")
 
-    if is_sdist_cached | is_wheel_cached:
+    if is_sdist_cached or is_wheel_cached:
         cached_sdist = fixture_dir("distributions") / "demo-0.1.0.tar.gz"
         cached_wheel = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
 
-        def mock_get_cached_archive_for_link_func(
-            _: Link, *, strict: bool, **__: Any
+        def mock_get_cached_archive_func(
+            _cache_dir: Path, *, strict: bool, **__: Any
         ) -> Path | None:
             if is_wheel_cached and not strict:
                 return cached_wheel
@@ -914,8 +919,8 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
             return None
 
         mocker.patch(
-            "poetry.installation.executor.ArtifactCache.get_cached_archive_for_link",
-            side_effect=mock_get_cached_archive_for_link_func,
+            "poetry.utils.cache.ArtifactCache._get_cached_archive",
+            side_effect=mock_get_cached_archive_func,
         )
 
     package = Package(
@@ -928,7 +933,7 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
     package.files = [
         {
             "file": "demo-0.1.0.tar.gz",
-            "hash": "sha256:9fa123ad707a5c6c944743bf3e11a0e80d86cb518d3cf25320866ca3ef43e2ad",  # noqa: E501
+            "hash": "sha256:9fa123ad707a5c6c944743bf3e11a0e80d86cb518d3cf25320866ca3ef43e2ad",
         }
     ]
 
@@ -955,9 +960,10 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
     if expect_artifact_download:
         assert package.source_url is not None
         download_spy.assert_called_once_with(
-            mocker.ANY, operation, Link(package.source_url)
+            mocker.ANY, operation, package.source_url, dest=mocker.ANY
         )
-        assert download_spy.spy_return.exists(), "cached file should not be deleted"
+        dest = download_spy.call_args.args[3]
+        assert dest.exists(), "cached file should not be deleted"
     else:
         download_spy.assert_not_called()
 
@@ -978,7 +984,7 @@ def test_executor_should_write_pep610_url_references_for_git(
     if is_artifact_cached:
         link_cached = fixture_dir("distributions") / "demo-0.1.2-py2.py3-none-any.whl"
         mocker.patch(
-            "poetry.installation.executor.ArtifactCache.get_cached_archive_for_git",
+            "poetry.utils.cache.ArtifactCache.get_cached_archive_for_git",
             return_value=link_cached,
         )
     clone_spy = mocker.spy(Git, "clone")
@@ -1238,9 +1244,17 @@ Package operations: 1 install, 0 updates, 0 removals
 
 
 @pytest.mark.parametrize("failing_method", ["build", "get_requires_for_build"])
+@pytest.mark.parametrize(
+    "exception",
+    [
+        CalledProcessError(1, ["pip"], output=b"original error"),
+        Exception("original error"),
+    ],
+)
 @pytest.mark.parametrize("editable", [False, True])
 def test_build_backend_errors_are_reported_correctly_if_caused_by_subprocess(
     failing_method: str,
+    exception: Exception,
     editable: bool,
     mocker: MockerFixture,
     config: Config,
@@ -1250,9 +1264,7 @@ def test_build_backend_errors_are_reported_correctly_if_caused_by_subprocess(
     env: MockEnv,
     fixture_dir: FixtureDirGetter,
 ) -> None:
-    error = BuildBackendException(
-        CalledProcessError(1, ["pip"], output=b"Error on stdout")
-    )
+    error = BuildBackendException(exception, description="hide the original error")
     mocker.patch.object(ProjectBuilder, failing_method, side_effect=error)
     io.set_verbosity(Verbosity.NORMAL)
 
@@ -1282,19 +1294,19 @@ Package operations: 1 install, 0 updates, 0 removals
 
   ChefBuildError
 
-  Backend operation failed: CalledProcessError(1, ['pip'])
+  hide the original error
   \
 
-  Error on stdout
+  original error
 """
 
     assert directory_package.source_url is not None
     if editable:
-        pip_command = "pip wheel --use-pep517 --editable"
+        pip_command = "pip wheel --no-cache-dir --use-pep517 --editable"
         requirement = directory_package.source_url
         assert Path(requirement).exists()
     else:
-        pip_command = "pip wheel --use-pep517"
+        pip_command = "pip wheel --no-cache-dir --use-pep517"
         requirement = f"{package_name} @ {path_to_url(directory_package.source_url)}"
     expected_end = f"""
 Note: This error originates from the build backend, and is likely not a problem with \
@@ -1372,11 +1384,7 @@ def test_build_system_requires_not_available(
         .as_posix(),
     )
 
-    return_code = executor.execute(
-        [
-            Install(directory_package),
-        ]
-    )
+    return_code = executor.execute([Install(directory_package)])
 
     assert return_code == 1
 
@@ -1396,3 +1404,99 @@ Package operations: 1 install, 0 updates, 0 removals
     output = io.fetch_output().strip()
     assert output.startswith(expected_start)
     assert output.endswith(expected_end)
+
+
+def test_build_system_requires_install_failure(
+    mocker: MockerFixture,
+    config: Config,
+    pool: RepositoryPool,
+    io: BufferedIO,
+    mock_file_downloads: None,
+    env: MockEnv,
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    mocker.patch("poetry.installation.installer.Installer.run", return_value=1)
+    mocker.patch("cleo.io.buffered_io.BufferedIO.fetch_output", return_value="output")
+    mocker.patch("cleo.io.buffered_io.BufferedIO.fetch_error", return_value="error")
+    io.set_verbosity(Verbosity.NORMAL)
+
+    executor = Executor(env, pool, config, io)
+
+    package_name = "simple-project"
+    package_version = "1.2.3"
+    directory_package = Package(
+        package_name,
+        package_version,
+        source_type="directory",
+        source_url=fixture_dir("simple_project").resolve().as_posix(),
+    )
+
+    return_code = executor.execute([Install(directory_package)])
+
+    assert return_code == 1
+
+    package_url = directory_package.source_url
+    expected_start = f"""\
+Package operations: 1 install, 0 updates, 0 removals
+
+  • Installing {package_name} ({package_version} {package_url})
+
+  ChefInstallError
+
+  Failed to install poetry-core>=1.1.0a7.
+  \
+
+  Output:
+  output
+  \
+
+  Error:
+  error
+
+"""
+    expected_end = "Cannot install build-system.requires for simple-project."
+
+    mocker.stopall()  # to get real output
+    output = io.fetch_output().strip()
+    assert output.startswith(expected_start)
+    assert output.endswith(expected_end)
+
+
+def test_other_error(
+    config: Config,
+    pool: RepositoryPool,
+    io: BufferedIO,
+    mock_file_downloads: None,
+    env: MockEnv,
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    io.set_verbosity(Verbosity.NORMAL)
+
+    executor = Executor(env, pool, config, io)
+
+    package_name = "simple-project"
+    package_version = "1.2.3"
+    directory_package = Package(
+        package_name,
+        package_version,
+        source_type="directory",
+        source_url=fixture_dir("non-existing").resolve().as_posix(),
+    )
+
+    return_code = executor.execute([Install(directory_package)])
+
+    assert return_code == 1
+
+    package_url = directory_package.source_url
+    expected_start = f"""\
+Package operations: 1 install, 0 updates, 0 removals
+
+  • Installing {package_name} ({package_version} {package_url})
+
+  FileNotFoundError
+"""
+    expected_end = "Cannot install simple-project."
+
+    output = io.fetch_output().strip()
+    assert output.startswith(expected_start)
+    assert output.endswith(expected_end)
