@@ -1,6 +1,8 @@
 from __future__ import annotations
 
+import contextlib
 import os
+import site
 import subprocess
 import sys
 
@@ -18,7 +20,7 @@ from poetry.factory import Factory
 from poetry.repositories.installed_repository import InstalledRepository
 from poetry.toml.file import TOMLFile
 from poetry.utils._compat import WINDOWS
-from poetry.utils.env import GET_BASE_PREFIX
+from poetry.utils._compat import metadata
 from poetry.utils.env import GET_PYTHON_VERSION_ONELINER
 from poetry.utils.env import EnvCommandError
 from poetry.utils.env import EnvManager
@@ -131,17 +133,6 @@ def test_env_commands_with_spaces_in_their_arg_work_as_expected(
     )
 
 
-def test_env_shell_commands_with_stdinput_in_their_arg_work_as_expected(
-    tmp_path: Path, manager: EnvManager
-) -> None:
-    venv_path = tmp_path / "Virtual Env"
-    manager.build_venv(venv_path)
-    venv = VirtualEnv(venv_path)
-    run_output_path = Path(venv.run("python", "-", input_=GET_BASE_PREFIX).strip())
-    venv_base_prefix_path = Path(str(venv.get_base_prefix()))
-    assert run_output_path.resolve() == venv_base_prefix_path.resolve()
-
-
 def test_env_get_supported_tags_matches_inside_virtualenv(
     tmp_path: Path, manager: EnvManager
 ) -> None:
@@ -192,18 +183,29 @@ def check_output_wrapper(
 ) -> Callable[[list[str], Any, Any], str]:
     def check_output(cmd: list[str], *args: Any, **kwargs: Any) -> str:
         # cmd is a list, like ["python", "-c", "do stuff"]
-        python_cmd = cmd[2]
+        python_cmd = cmd[-1]
+        if "print(json.dumps(env))" in python_cmd:
+            return (
+                f'{{"version_info": [{version.major}, {version.minor},'
+                f" {version.patch}]}}"
+            )
+
         if "sys.version_info[:3]" in python_cmd:
             return version.text
-        elif "sys.version_info[:2]" in python_cmd:
+
+        if "sys.version_info[:2]" in python_cmd:
             return f"{version.major}.{version.minor}"
-        elif "import sys; print(sys.executable)" in python_cmd:
+
+        if "import sys; print(sys.executable)" in python_cmd:
             executable = cmd[0]
             basename = os.path.basename(executable)
             return f"/usr/bin/{basename}"
-        else:
-            assert "import sys; print(sys.prefix)" in python_cmd
-            return "/prefix"
+
+        if "print(sys.base_prefix)" in python_cmd:
+            return "/usr"
+
+        assert "import sys; print(sys.prefix)" in python_cmd
+        return "/prefix"
 
     return check_output
 
@@ -221,22 +223,12 @@ def test_activate_in_project_venv_no_explicit_config(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[
-            ("/prefix", None),
-            ('{"version_info": [3, 7, 0]}', None),
-            ("/prefix", None),
-            ("/prefix", None),
-            ("/prefix", None),
-        ],
-    )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
     env = manager.activate("python3.7")
 
     assert env.path == tmp_path / "poetry-fixture-simple" / ".venv"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
 
     m.assert_called_with(
         tmp_path / "poetry-fixture-simple" / ".venv",
@@ -273,10 +265,6 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None), ("/prefix", None)],
-    )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
     env = manager.activate("python3.7")
@@ -296,7 +284,7 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
     assert envs[venv_name]["patch"] == "3.7.1"
 
     assert env.path == tmp_path / f"{venv_name}-py3.7"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
 
 
 def test_activate_fails_when_python_cannot_be_found(
@@ -343,10 +331,6 @@ def test_activate_activates_existing_virtualenv_no_envs_file(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None)],
-    )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
     env = manager.activate("python3.7")
@@ -360,7 +344,7 @@ def test_activate_activates_existing_virtualenv_no_envs_file(
     assert envs[venv_name]["patch"] == "3.7.1"
 
     assert env.path == tmp_path / f"{venv_name}-py3.7"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
 
 
 def test_activate_activates_same_virtualenv_with_envs_file(
@@ -388,10 +372,6 @@ def test_activate_activates_same_virtualenv_with_envs_file(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None)],
-    )
     m = mocker.patch("poetry.utils.env.EnvManager.create_venv")
 
     env = manager.activate("python3.7")
@@ -404,7 +384,7 @@ def test_activate_activates_same_virtualenv_with_envs_file(
     assert envs[venv_name]["patch"] == "3.7.1"
 
     assert env.path == tmp_path / f"{venv_name}-py3.7"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
 
 
 def test_activate_activates_different_virtualenv_with_envs_file(
@@ -433,10 +413,6 @@ def test_activate_activates_different_virtualenv_with_envs_file(
         "subprocess.check_output",
         side_effect=check_output_wrapper(Version.parse("3.6.6")),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None), ("/prefix", None), ("/prefix", None)],
-    )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
     env = manager.activate("python3.6")
@@ -454,7 +430,7 @@ def test_activate_activates_different_virtualenv_with_envs_file(
     assert envs[venv_name]["patch"] == "3.6.6"
 
     assert env.path == tmp_path / f"{venv_name}-py3.6"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
 
 
 def test_activate_activates_recreates_for_different_patch(
@@ -483,16 +459,6 @@ def test_activate_activates_recreates_for_different_patch(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[
-            ("/prefix", None),
-            ('{"version_info": [3, 7, 0]}', None),
-            ("/prefix", None),
-            ("/prefix", None),
-            ("/prefix", None),
-        ],
-    )
     build_venv_m = mocker.patch(
         "poetry.utils.env.EnvManager.build_venv", side_effect=build_venv
     )
@@ -516,7 +482,7 @@ def test_activate_activates_recreates_for_different_patch(
     assert envs[venv_name]["patch"] == "3.7.1"
 
     assert env.path == tmp_path / f"{venv_name}-py3.7"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
     assert (tmp_path / f"{venv_name}-py3.7").exists()
 
 
@@ -546,10 +512,6 @@ def test_activate_does_not_recreate_when_switching_minor(
         "subprocess.check_output",
         side_effect=check_output_wrapper(Version.parse("3.6.6")),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None), ("/prefix", None), ("/prefix", None)],
-    )
     build_venv_m = mocker.patch(
         "poetry.utils.env.EnvManager.build_venv", side_effect=build_venv
     )
@@ -568,7 +530,7 @@ def test_activate_does_not_recreate_when_switching_minor(
     assert envs[venv_name]["patch"] == "3.6.6"
 
     assert env.path == tmp_path / f"{venv_name}-py3.6"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
     assert (tmp_path / f"{venv_name}-py3.6").exists()
 
 
@@ -661,15 +623,11 @@ def test_get_prefers_explicitly_activated_virtualenvs_over_env_var(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None)],
-    )
 
     env = manager.get()
 
     assert env.path == tmp_path / f"{venv_name}-py3.7"
-    assert env.base == Path("/prefix")
+    assert env.base == Path("/usr")
 
 
 def test_list(
@@ -965,40 +923,16 @@ def test_env_has_symlinks_on_nix(tmp_path: Path, tmp_venv: VirtualEnv) -> None:
     assert os.path.islink(tmp_venv.python)
 
 
-def test_run_with_input(tmp_path: Path, tmp_venv: VirtualEnv) -> None:
-    result = tmp_venv.run("python", "-", input_=MINIMAL_SCRIPT)
-
-    assert result == "Minimal Output\n"
-
-
-def test_run_with_input_non_zero_return(tmp_path: Path, tmp_venv: VirtualEnv) -> None:
-    with pytest.raises(EnvCommandError) as process_error:
-        # Test command that will return non-zero returncode.
-        tmp_venv.run("python", "-", input_=ERRORING_SCRIPT)
-
-    assert process_error.value.e.returncode == 1
-
-
 def test_run_with_keyboard_interrupt(
     tmp_path: Path, tmp_venv: VirtualEnv, mocker: MockerFixture
 ) -> None:
-    mocker.patch("subprocess.run", side_effect=KeyboardInterrupt())
+    mocker.patch("subprocess.check_output", side_effect=KeyboardInterrupt())
     with pytest.raises(KeyboardInterrupt):
-        tmp_venv.run("python", "-", input_=MINIMAL_SCRIPT)
-    subprocess.run.assert_called_once()  # type: ignore[attr-defined]
+        tmp_venv.run("python", "-c", MINIMAL_SCRIPT)
+    subprocess.check_output.assert_called_once()  # type: ignore[attr-defined]
 
 
-def test_call_with_input_and_keyboard_interrupt(
-    tmp_path: Path, tmp_venv: VirtualEnv, mocker: MockerFixture
-) -> None:
-    mocker.patch("subprocess.run", side_effect=KeyboardInterrupt())
-    kwargs = {"call": True}
-    with pytest.raises(KeyboardInterrupt):
-        tmp_venv.run("python", "-", input_=MINIMAL_SCRIPT, **kwargs)
-    subprocess.run.assert_called_once()  # type: ignore[attr-defined]
-
-
-def test_call_no_input_with_keyboard_interrupt(
+def test_call_with_keyboard_interrupt(
     tmp_path: Path, tmp_venv: VirtualEnv, mocker: MockerFixture
 ) -> None:
     mocker.patch("subprocess.check_call", side_effect=KeyboardInterrupt())
@@ -1012,31 +946,14 @@ def test_run_with_called_process_error(
     tmp_path: Path, tmp_venv: VirtualEnv, mocker: MockerFixture
 ) -> None:
     mocker.patch(
-        "subprocess.run",
+        "subprocess.check_output",
         side_effect=subprocess.CalledProcessError(
             42, "some_command", "some output", "some error"
         ),
     )
     with pytest.raises(EnvCommandError) as error:
-        tmp_venv.run("python", "-", input_=MINIMAL_SCRIPT)
-    subprocess.run.assert_called_once()  # type: ignore[attr-defined]
-    assert "some output" in str(error.value)
-    assert "some error" in str(error.value)
-
-
-def test_call_with_input_and_called_process_error(
-    tmp_path: Path, tmp_venv: VirtualEnv, mocker: MockerFixture
-) -> None:
-    mocker.patch(
-        "subprocess.run",
-        side_effect=subprocess.CalledProcessError(
-            42, "some_command", "some output", "some error"
-        ),
-    )
-    kwargs = {"call": True}
-    with pytest.raises(EnvCommandError) as error:
-        tmp_venv.run("python", "-", input_=MINIMAL_SCRIPT, **kwargs)
-    subprocess.run.assert_called_once()  # type: ignore[attr-defined]
+        tmp_venv.run("python", "-c", MINIMAL_SCRIPT)
+    subprocess.check_output.assert_called_once()  # type: ignore[attr-defined]
     assert "some output" in str(error.value)
     assert "some error" in str(error.value)
 
@@ -1121,7 +1038,7 @@ def test_run_python_script_only_stdout(tmp_path: Path, tmp_venv: VirtualEnv) ->
     assert "some warning" not in output
 
 
-def test_create_venv_tries_to_find_a_compatible_python_executable_using_generic_ones_first(  # noqa: E501
+def test_create_venv_tries_to_find_a_compatible_python_executable_using_generic_ones_first(
     manager: EnvManager,
     poetry: Poetry,
     config: Config,
@@ -1201,7 +1118,13 @@ def test_create_venv_tries_to_find_a_compatible_python_executable_using_specific
     mocker.patch("shutil.which", side_effect=lambda py: f"/usr/bin/{py}")
     mocker.patch(
         "subprocess.check_output",
-        side_effect=["/usr/bin/python3", "3.5.3", "/usr/bin/python3.9", "3.9.0"],
+        side_effect=[
+            "/usr/bin/python3",
+            "3.5.3",
+            "/usr/bin/python3.9",
+            "3.9.0",
+            "/usr",
+        ],
     )
     m = mocker.patch(
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
@@ -1288,7 +1211,7 @@ def test_create_venv_uses_patch_version_to_detect_compatibility(
 
     assert version.patch is not None
     mocker.patch("sys.version_info", (version.major, version.minor, version.patch + 1))
-    check_output = mocker.patch(
+    mocker.patch(
         "subprocess.check_output",
         side_effect=check_output_wrapper(Version.parse("3.6.9")),
     )
@@ -1298,7 +1221,6 @@ def test_create_venv_uses_patch_version_to_detect_compatibility(
 
     manager.create_venv()
 
-    assert not check_output.called
     m.assert_called_with(
         config_virtualenvs_path / f"{venv_name}-py{version.major}.{version.minor}",
         executable=None,
@@ -1400,10 +1322,6 @@ def test_activate_with_in_project_setting_does_not_fail_if_no_venvs_dir(
         "subprocess.check_output",
         side_effect=check_output_wrapper(),
     )
-    mocker.patch(
-        "subprocess.Popen.communicate",
-        side_effect=[("/prefix", None), ("/prefix", None), ("/prefix", None)],
-    )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv")
 
     manager.activate("python3.7")
@@ -1457,30 +1375,70 @@ def test_venv_has_correct_paths(tmp_venv: VirtualEnv) -> None:
     )
 
 
-def test_env_system_packages(tmp_path: Path, poetry: Poetry) -> None:
+@pytest.mark.parametrize("with_system_site_packages", [True, False])
+def test_env_system_packages(
+    tmp_path: Path, poetry: Poetry, with_system_site_packages: bool
+) -> None:
     venv_path = tmp_path / "venv"
     pyvenv_cfg = venv_path / "pyvenv.cfg"
 
-    EnvManager(poetry).build_venv(path=venv_path, flags={"system-site-packages": True})
+    EnvManager(poetry).build_venv(
+        path=venv_path, flags={"system-site-packages": with_system_site_packages}
+    )
+    env = VirtualEnv(venv_path)
 
-    assert "include-system-site-packages = true" in pyvenv_cfg.read_text()
+    assert (
+        f"include-system-site-packages = {str(with_system_site_packages).lower()}"
+        in pyvenv_cfg.read_text()
+    )
+    assert env.includes_system_site_packages is with_system_site_packages
+
+
+def test_generic_env_system_packages(poetry: Poetry) -> None:
+    """https://github.com/python-poetry/poetry/issues/8646"""
+    env = GenericEnv(Path(sys.base_prefix))
+    assert not env.includes_system_site_packages
+
+
+@pytest.mark.parametrize("with_system_site_packages", [True, False])
+def test_env_system_packages_are_relative_to_lib(
+    tmp_path: Path, poetry: Poetry, with_system_site_packages: bool
+) -> None:
+    venv_path = tmp_path / "venv"
+    EnvManager(poetry).build_venv(
+        path=venv_path, flags={"system-site-packages": with_system_site_packages}
+    )
+    env = VirtualEnv(venv_path)
+    site_dir = Path(site.getsitepackages()[-1])
+    for dist in metadata.distributions():
+        # Emulate is_relative_to, only available in 3.9+
+        with contextlib.suppress(ValueError):
+            dist._path.relative_to(site_dir)  # type: ignore[attr-defined]
+            break
+    assert (
+        env.is_path_relative_to_lib(dist._path)  # type: ignore[attr-defined]
+        is with_system_site_packages
+    )
 
 
 @pytest.mark.parametrize(
     ("flags", "packages"),
     [
-        ({"no-pip": False}, {"pip", "wheel"}),
+        ({"no-pip": False}, {"pip"}),
         ({"no-pip": False, "no-wheel": True}, {"pip"}),
+        ({"no-pip": False, "no-wheel": False}, {"pip", "wheel"}),
         ({"no-pip": True}, set()),
         ({"no-setuptools": False}, {"setuptools"}),
         ({"no-setuptools": True}, set()),
+        ({"setuptools": "bundle"}, {"setuptools"}),
         ({"no-pip": True, "no-setuptools": False}, {"setuptools"}),
         ({"no-wheel": False}, {"wheel"}),
+        ({"wheel": "bundle"}, {"wheel"}),
         ({}, set()),
     ],
 )
 def test_env_no_pip(
-    tmp_path: Path, poetry: Poetry, flags: dict[str, bool], packages: set[str]
+    tmp_path: Path, poetry: Poetry, flags: dict[str, str | bool], packages: set[str]
 ) -> None:
     venv_path = tmp_path / "venv"
     EnvManager(poetry).build_venv(path=venv_path, flags=flags)
@@ -1493,6 +1451,14 @@ def test_env_no_pip(
         if package.name != "sqlite3"
     }
 
+    # For python >= 3.12, virtualenv defaults to "--no-setuptools" and "--no-wheel"
+    # behaviour, so setting these values to False becomes meaningless.
+    if sys.version_info >= (3, 12):
+        if not flags.get("no-setuptools", True):
+            packages.discard("setuptools")
+        if not flags.get("no-wheel", True):
+            packages.discard("wheel")
+
     assert installed_packages == packages
 
 
